==> freebsd-ubin-8.2.tar.bz2: usr.bin/finger/extern.h <==
/*-
 * Copyright (c) 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)extern.h	8.2 (Berkeley) 4/28/95
 * $FreeBSD: src/usr.bin/finger/extern.h,v 1.11.10.1.6.1 2010/12/21 17:09:25 kensmith Exp $
 */

#ifndef	_EXTERN_H_
#define	_EXTERN_H_

extern char tbuf[1024];			/* Temp buffer for anybody. */
extern int entries;			/* Number of people. */
extern DB *db;				/* Database. */
extern int d_first;
extern sa_family_t family;
extern int gflag;
extern int lflag;
extern time_t now;
extern int oflag;
extern int pplan;			/* don't show .plan/.project */
extern int invoker_root;		/* Invoked by root */

void	 enter_lastlog(PERSON *);
PERSON	*enter_person(struct passwd *);
void	 enter_where(struct utmp *, PERSON *);
PERSON	*find_person(const char *);
int	 hide(struct passwd *);
void	 lflag_print(void);
int	 match(struct passwd *, const char *);
void	 netfinger(char *);
PERSON	*palloc(void);
char	*prphone(char *);
void	 sflag_print(void);
int	 show_text(const char *, const char *, const char *);

#endif /* !_EXTERN_H_ */

==> freebsd-ubin-9.2_rc2.tar.bz2: usr.bin/finger/extern.h <==
/*-
 * Copyright (c) 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)extern.h	8.2 (Berkeley) 4/28/95
 * $FreeBSD: releng/9.2/usr.bin/finger/extern.h 216370 2010-12-11 08:32:16Z joel $
 */

#ifndef	_EXTERN_H_
#define	_EXTERN_H_

extern char tbuf[1024];			/* Temp buffer for anybody. */
extern int entries;			/* Number of people. */
extern DB *db;				/* Database. */
extern int d_first;
extern sa_family_t family;
extern int gflag;
extern int lflag;
extern time_t now;
extern int oflag;
extern int pplan;			/* don't show .plan/.project */
extern int invoker_root;		/* Invoked by root */

void	 enter_lastlog(PERSON *);
PERSON	*enter_person(struct passwd *);
void	 enter_where(struct utmpx *, PERSON *);
PERSON	*find_person(char *);
int	 hide(struct passwd *);
void	 lflag_print(void);
int	 match(struct passwd *, const char *);
void	 netfinger(char *);
PERSON	*palloc(void);
char	*prphone(char *);
void	 sflag_print(void);
int	 show_text(const char *, const char *, const char *);

#endif /* !_EXTERN_H_ */
